@@ -1,22 +1,23 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-/* $Id: weather-metar.c 10286 2007-07-12 08:52:56Z callum $ */
-
-/*
- *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
+/* weather-metar.c - Weather server functions (METAR)
  *
- *  This code released under the GNU GPL.
- *  Read the file COPYING for more information.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- *  Weather server functions (METAR)
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
  *
- */
-
-/*
- * Code for parsing METAR weather observations
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <stdlib.h>
@@ -26,7 +27,7 @@
 #include <glib/gi18n-lib.h>
 
 #define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
-#include <libgweather/weather.h>
+#include "weather.h"
 #include "weather-priv.h"
 
 
